summaryrefslogtreecommitdiffstats
path: root/tdecore/klibloader.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/klibloader.h')
-rw-r--r--tdecore/klibloader.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/tdecore/klibloader.h b/tdecore/klibloader.h
index 10df2c445..9f080b88b 100644
--- a/tdecore/klibloader.h
+++ b/tdecore/klibloader.h
@@ -27,7 +27,7 @@
#include <stdlib.h> // For backwards compatibility
-class KInstance;
+class TDEInstance;
class TQTimer;
class KLibrary;
class KLibFactory;
@@ -271,9 +271,9 @@ public:
* @param name of the library. If it is not a path, the function searches in
* the "module" and "lib" resources. If there is no extension,
* ".la" will be appended.
* @param instance a KInstance used to get the standard paths
*/
- static TQString findLibrary( const char * name, const KInstance * instance = KGlobal::instance() );
+ static TQString findLibrary( const char * name, const TDEInstance * instance = KGlobal::instance() );
protected:
KLibLoader( TQObject* parent = 0, const char* name = 0 );
@@ -306,12 +306,12 @@ private:
* NOTE: you probably want to use KGenericFactory<PluginClassName>
* instead of writing your own factory.
*
* In the constructor of your factory you should create an instance of KInstance
* like this:
* \code
- * s_global = new KInstance( "kspread" );
+ * s_global = new TDEInstance( "kspread" );
* \endcode
* This KInstance is comparable to KGlobal used by normal applications.
* It allows you to find resource files (images, XML, sound etc.) belonging
* to the library.
*
@@ -271,9 +271,9 @@ public:
* the "module" and "lib" resources. If there is no extension,
* ".la" will be appended.
- * @param instance a KInstance used to get the standard paths
+ * @param instance a TDEInstance used to get the standard paths
*/
@@ -306,12 +306,12 @@ private:
* instead of writing your own factory.
*
- * In the constructor of your factory you should create an instance of KInstance
+ * In the constructor of your factory you should create an instance of TDEInstance
* like this:
* \code
@@ -306,12 +306,12 @@ private:
* \endcode
- * This KInstance is comparable to KGlobal used by normal applications.
+ * This TDEInstance is comparable to KGlobal used by normal applications.
* It allows you to find resource files (images, XML, sound etc.) belonging
* to the library.